<?php
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/auth.php';
if (session_status() === PHP_SESSION_NONE) session_start();
requireLogin();
if ($_SESSION['user']['group_id'] < 3) exit('Unauthorized');

$category_id = isset($_GET['category_id']) ? (int) $_GET['category_id'] : 0;
$stmt = $db->prepare("SELECT name FROM link_categories WHERE id = ?");
$stmt->bind_param("i", $category_id);
$stmt->execute();
$stmt->bind_result($category_name);
if (!$stmt->fetch()) exit('Category not found');
$stmt->close();

$name = '';
$url = '';
$errors = [];
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $url  = trim($_POST['url']);
    if (!$name) $errors[] = 'Link name is required.';
    if (!$url || !filter_var($url, FILTER_VALIDATE_URL)) $errors[] = 'Valid URL is required.';
    if (empty($errors)) {
        $stmt = $db->prepare("INSERT INTO category_links (category_id, name, url) VALUES (?, ?, ?)");
        $stmt->bind_param("iss", $category_id, $name, $url);
        $stmt->execute();
        header("Location: links.php?category_id=$category_id");
        exit;
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Link Vault - Add Link</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
  <h1>Add New Link to "<?= htmlspecialchars($category_name) ?>"</h1>
  <?php if ($errors): ?><div class="errors"><?= implode('<br>', $errors) ?></div><?php endif; ?>
  <form method="post">
    <label>Name</label>
    <input type="text" name="name" value="<?= htmlspecialchars($name) ?>" required>
    <label>URL</label>
    <input type="text" name="url" value="<?= htmlspecialchars($url) ?>" required>
    <button type="submit">Save Link</button>
    <a href="links.php?category_id=<?= $category_id ?>">Cancel</a>
  </form>
</div>
</body>
</html>