<?php
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/auth.php';
if (session_status() === PHP_SESSION_NONE) session_start();
requireLogin();
if ($_SESSION['user']['group_id'] < 3) exit('Unauthorized');

$id = isset($_GET['id']) ? (int) $_GET['id'] : 0;
$stmt = $db->prepare("SELECT name FROM link_categories WHERE id = ?");
$stmt->bind_param("i", $id);
$stmt->execute();
$stmt->bind_result($name);
if (!$stmt->fetch()) exit('Category not found');
$stmt->close();

$errors = [];
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $new_name = trim($_POST['name']);
    if (!$new_name) $errors[] = 'Name is required.';
    if (empty($errors)) {
        $stmt = $db->prepare("UPDATE link_categories SET name = ? WHERE id = ?");
        $stmt->bind_param("si", $new_name, $id);
        $stmt->execute();
        header('Location: categories.php');
        exit;
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Link Vault - Edit Category</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
  <h1>Edit Category</h1>
  <?php if ($errors): ?><div class="errors"><?= implode('<br>', $errors) ?></div><?php endif; ?>
  <form method="post">
    <label>Name</label>
    <input type="text" name="name" value="<?= htmlspecialchars($name) ?>" required>
    <button type="submit">Save Changes</button>
    <a href="categories.php">Cancel</a>
  </form>
</div>
</body>
</html>
