<?php
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/auth.php';
if (session_status() === PHP_SESSION_NONE) session_start();
requireLogin();
if ($_SESSION['user']['group_id'] < 3) exit('Unauthorized');

$id = isset($_GET['id']) ? (int) $_GET['id'] : 0;
$category_id = isset($_GET['category_id']) ? (int) $_GET['category_id'] : 0;
$stmt = $db->prepare("SELECT name, url FROM category_links WHERE id = ? AND category_id = ?");
$stmt->bind_param("ii", $id, $category_id);
$stmt->execute();
$stmt->bind_result($name, $url);
if (!$stmt->fetch()) exit('Link not found');
$stmt->close();

$errors = [];
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $new_name = trim($_POST['name']);
    $new_url  = trim($_POST['url']);
    if (!$new_name) $errors[] = 'Link name is required.';
    if (!$new_url || !filter_var($new_url, FILTER_VALIDATE_URL)) $errors[] = 'Valid URL is required.';
    if (empty($errors)) {
        $stmt = $db->prepare("UPDATE category_links SET name = ?, url = ? WHERE id = ? AND category_id = ?");
        $stmt->bind_param("ssii", $new_name, $new_url, $id, $category_id);
        $stmt->execute();
        header("Location: links.php?category_id=$category_id");
        exit;
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Link Vault - Edit Link</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
  <h1>Edit Link in "<?= htmlspecialchars(getCategoryName($category_id, $db)) ?>"</h1>
  <?php if ($errors): ?><div class="errors"><?= implode('<br>', $errors) ?></div><?php endif; ?>
  <form method="post">
    <label>Name</label>
    <input type="text" name="name" value="<?= htmlspecialchars($name) ?>" required>
    <label>URL</label>
    <input type="text" name="url" value="<?= htmlspecialchars($url) ?>" required>
    <button type="submit">Save Changes</button>
    <a href="links.php?category_id=<?= $category_id ?>">Cancel</a>
  </form>
</div>
</body>
</html>
