<?php
// File: admin/links.php
// Manage links for a given category
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/auth.php';
if (session_status() === PHP_SESSION_NONE) session_start();
requireLogin();
if ($_SESSION['user']['group_id'] < 3) exit('Unauthorized');

$category_id = isset($_GET['category_id']) ? (int) $_GET['category_id'] : 0;
// Fetch category
$stmt = $db->prepare("SELECT id, name FROM link_categories WHERE id = ?");
$stmt->bind_param("i", $category_id);
$stmt->execute();
$category = $stmt->get_result()->fetch_assoc();
if (!$category) exit('Category not found');

// Handle delete link
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $stmt = $db->prepare("DELETE FROM category_links WHERE id = ?");
    $stmt->bind_param("i", $_GET['delete']);
    $stmt->execute();
    header("Location: links.php?category_id=$category_id"); exit;
}

// Fetch links
$stmt = $db->prepare("SELECT id, name, url FROM category_links WHERE category_id = ? ORDER BY name");
$stmt->bind_param("i", $category_id);
$stmt->execute();
$links = $stmt->get_result();
?>
<!DOCTYPE html>
<html>
<head>
    <title>Link Vault</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
  <h1>Links in &ldquo;<?= htmlspecialchars($category['name']) ?>&rdquo;</h1>
  <a href="add_link.php?category_id=<?= $category_id ?>" class="btn">Add New Link</a>
  <table class="table">
    <thead><tr><th>Name</th><th>URL</th><th>Edit</th><th>Delete</th></tr></thead>
    <tbody>
      <?php while ($link = $links->fetch_assoc()): ?>
        <tr>
          <td><?= htmlspecialchars($link['name']) ?></td>
          <td><a href="<?= htmlspecialchars($link['url']) ?>" target="_blank"><?= htmlspecialchars($link['url']) ?></a></td>
          <td><a href="edit_link.php?id=<?= $link['id'] ?>&category_id=<?= $category_id ?>">Edit</a></td>
          <td><a href="links.php?category_id=<?= $category_id ?>&delete=<?= $link['id'] ?>" onclick="return confirm('Delete link?');">Delete</a></td>
        </tr>
      <?php endwhile; ?>
    </tbody>
  </table>
  <p><a href="categories.php">Back to Categories</a></p>
</div>
</body>
</html>